complete -c dprint -n "__fish_use_subcommand" -s c -l config -d 'Path or url to JSON configuration file. Defaults to dprint.json(c) or .dprint.json(c) in current or ancestor directory when not provided.' -r -F
complete -c dprint -n "__fish_use_subcommand" -l config-discovery -d 'Sets the config discovery mode. Set to `false` to completely disable, `ignore-descendants` to avoid finding config files in child directories, or `global` to only use the global config file.' -r
complete -c dprint -n "__fish_use_subcommand" -l plugins -d 'List of urls or file paths of plugins to use. This overrides what is specified in the config file.' -r -F
complete -c dprint -n "__fish_use_subcommand" -s L -l log-level -d 'Set log level' -r -f -a "{debug	'',info	'',warn	'',error	'',silent	''}"
complete -c dprint -n "__fish_use_subcommand" -l verbose -d 'Alias for --log-level=debug'
complete -c dprint -n "__fish_use_subcommand" -s h -l help -d 'Print help'
complete -c dprint -n "__fish_use_subcommand" -s V -l version -d 'Print version'
complete -c dprint -n "__fish_use_subcommand" -f -a "init" -d 'Initializes a configuration file in the current directory.'
complete -c dprint -n "__fish_use_subcommand" -f -a "add" -d 'Adds a plugin to the configuration file.'
complete -c dprint -n "__fish_use_subcommand" -f -a "fmt" -d 'Formats the source files and writes the result to the file system.'
complete -c dprint -n "__fish_use_subcommand" -f -a "check" -d 'Checks for any files that haven\'t been formatted.'
complete -c dprint -n "__fish_use_subcommand" -f -a "config" -d 'Functionality related to the configuration file.'
complete -c dprint -n "__fish_use_subcommand" -f -a "file-paths" -d 'Prints the resolved file paths for the plugins based on the args and configuration.'
complete -c dprint -n "__fish_use_subcommand" -f -a "resolved-config" -d 'Prints the resolved configuration for the plugins based on the args and configuration.'
complete -c dprint -n "__fish_use_subcommand" -f -a "incremental-state" -d 'Prints the state used to determine whether the incremental cache would be invalidated.'
complete -c dprint -n "__fish_use_subcommand" -f -a "format-times" -d 'Prints the amount of time it takes to format each file. Use this for debugging.'
complete -c dprint -n "__fish_use_subcommand" -f -a "clear-cache" -d 'Deletes the plugin cache directory.'
complete -c dprint -n "__fish_use_subcommand" -f -a "upgrade" -d 'Upgrades the dprint executable.'
complete -c dprint -n "__fish_use_subcommand" -f -a "completions" -d 'Generate shell completions script for dprint'
complete -c dprint -n "__fish_use_subcommand" -f -a "license" -d 'Outputs the software license.'
complete -c dprint -n "__fish_use_subcommand" -f -a "editor-info"
complete -c dprint -n "__fish_use_subcommand" -f -a "editor-service"
complete -c dprint -n "__fish_use_subcommand" -f -a "lsp" -d 'Starts up a language server for formatting files.'
complete -c dprint -n "__fish_use_subcommand" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c dprint -n "__fish_seen_subcommand_from init" -l minimum-dependency-age -d 'Don\'t resolve npm plugin versions published more recently than this. Accepts an ISO-8601 duration (ex. \'P3D\', \'PT72H\'), a number of minutes (ex. \'1440\'), a date or RFC3339 timestamp (ex. \'2026-01-15\'), or \'0\' to disable. Defaults to min-release-age in .npmrc, otherwise no minimum.' -r
complete -c dprint -n "__fish_seen_subcommand_from init" -s c -l config -d 'Path or url to JSON configuration file. Defaults to dprint.json(c) or .dprint.json(c) in current or ancestor directory when not provided.' -r -F
complete -c dprint -n "__fish_seen_subcommand_from init" -l config-discovery -d 'Sets the config discovery mode. Set to `false` to completely disable, `ignore-descendants` to avoid finding config files in child directories, or `global` to only use the global config file.' -r
complete -c dprint -n "__fish_seen_subcommand_from init" -l plugins -d 'List of urls or file paths of plugins to use. This overrides what is specified in the config file.' -r -F
complete -c dprint -n "__fish_seen_subcommand_from init" -s L -l log-level -d 'Set log level' -r -f -a "{debug	'',info	'',warn	'',error	'',silent	''}"
complete -c dprint -n "__fish_seen_subcommand_from init" -s g -l global -d 'Initialize the global dprint configuration file.'
complete -c dprint -n "__fish_seen_subcommand_from init" -s y -l yes -d 'Skip the interactive plugin prompt and accept the plugins selected based on the files in the current directory.'
complete -c dprint -n "__fish_seen_subcommand_from init" -l verbose -d 'Alias for --log-level=debug'
complete -c dprint -n "__fish_seen_subcommand_from init" -s h -l help -d 'Print help'
complete -c dprint -n "__fish_seen_subcommand_from add" -l minimum-dependency-age -d 'Don\'t resolve npm plugin versions published more recently than this. Accepts an ISO-8601 duration (ex. \'P3D\', \'PT72H\'), a number of minutes (ex. \'1440\'), a date or RFC3339 timestamp (ex. \'2026-01-15\'), or \'0\' to disable. Defaults to min-release-age in .npmrc, otherwise no minimum.' -r
complete -c dprint -n "__fish_seen_subcommand_from add" -s c -l config -d 'Path or url to JSON configuration file. Defaults to dprint.json(c) or .dprint.json(c) in current or ancestor directory when not provided.' -r -F
complete -c dprint -n "__fish_seen_subcommand_from add" -l config-discovery -d 'Sets the config discovery mode. Set to `false` to completely disable, `ignore-descendants` to avoid finding config files in child directories, or `global` to only use the global config file.' -r
complete -c dprint -n "__fish_seen_subcommand_from add" -l plugins -d 'List of urls or file paths of plugins to use. This overrides what is specified in the config file.' -r -F
complete -c dprint -n "__fish_seen_subcommand_from add" -s L -l log-level -d 'Set log level' -r -f -a "{debug	'',info	'',warn	'',error	'',silent	''}"
complete -c dprint -n "__fish_seen_subcommand_from add" -s g -l global -d 'Add to the global dprint configuration file.'
complete -c dprint -n "__fish_seen_subcommand_from add" -l no-version -d 'For npm: specifiers, write the unversioned form instead of pinning dist-tags.latest. Defers version management to node_modules / package.json.'
complete -c dprint -n "__fish_seen_subcommand_from add" -l package-json -d 'Like --no-version, and also add the package to the nearest package.json\'s devDependencies as a caret range.'
complete -c dprint -n "__fish_seen_subcommand_from add" -l checksum -d 'Add a checksum to the plugin entry, even for Wasm plugins (which are otherwise added without one).'
complete -c dprint -n "__fish_seen_subcommand_from add" -l verbose -d 'Alias for --log-level=debug'
complete -c dprint -n "__fish_seen_subcommand_from add" -s h -l help -d 'Print help'
complete -c dprint -n "__fish_seen_subcommand_from fmt" -l includes-override -d 'List of file patterns in quotes to format. This overrides what is specified in the config file.' -r
complete -c dprint -n "__fish_seen_subcommand_from fmt" -l excludes -d 'List of file patterns or directories in quotes to exclude when formatting. This excludes in addition to what is found in the config file.' -r
complete -c dprint -n "__fish_seen_subcommand_from fmt" -l excludes-override -d 'List of file patterns or directories in quotes to exclude when formatting. This overrides what is specified in the config file.' -r
complete -c dprint -n "__fish_seen_subcommand_from fmt" -l incremental -d 'Only format files when they change. This may alternatively be specified in the configuration file.' -r -f -a "{true	'',false	''}"
complete -c dprint -n "__fish_seen_subcommand_from fmt" -l stdin -d 'Format stdin and output the result to stdout. Provide an absolute file path to apply the inclusion and exclusion rules or an extension or file name to always format the text.' -r -F
complete -c dprint -n "__fish_seen_subcommand_from fmt" -l diff-format -d 'The format to output diffs in. Use `unified` to output a standard unified diff that can be piped to other tools or applied with `patch`. Defaults to `pretty`, or `unified` when outputting json.' -r -f -a "{pretty	'',unified	''}"
complete -c dprint -n "__fish_seen_subcommand_from fmt" -s c -l config -d 'Path or url to JSON configuration file. Defaults to dprint.json(c) or .dprint.json(c) in current or ancestor directory when not provided.' -r -F
complete -c dprint -n "__fish_seen_subcommand_from fmt" -l config-discovery -d 'Sets the config discovery mode. Set to `false` to completely disable, `ignore-descendants` to avoid finding config files in child directories, or `global` to only use the global config file.' -r
complete -c dprint -n "__fish_seen_subcommand_from fmt" -l plugins -d 'List of urls or file paths of plugins to use. This overrides what is specified in the config file.' -r -F
complete -c dprint -n "__fish_seen_subcommand_from fmt" -s L -l log-level -d 'Set log level' -r -f -a "{debug	'',info	'',warn	'',error	'',silent	''}"
complete -c dprint -n "__fish_seen_subcommand_from fmt" -l stdin-files -d 'Read a newline-separated list of file paths to format from stdin instead of from the command line arguments.'
complete -c dprint -n "__fish_seen_subcommand_from fmt" -l allow-node-modules -d 'Allows traversing node module directories. This is implicit when the current working directory is within one (unstable - This flag will be renamed to be non-node specific in the future).'
complete -c dprint -n "__fish_seen_subcommand_from fmt" -l no-gitignore -d 'Disables respecting .gitignore files.'
complete -c dprint -n "__fish_seen_subcommand_from fmt" -l diff -d 'Outputs a check-like diff of every formatted file.'
complete -c dprint -n "__fish_seen_subcommand_from fmt" -l staged -d 'Format only the staged files.'
complete -c dprint -n "__fish_seen_subcommand_from fmt" -l dirty -d 'Format only the files with uncommitted changes in the git working directory (staged, unstaged, and untracked).'
complete -c dprint -n "__fish_seen_subcommand_from fmt" -l allow-no-files -d 'Causes dprint to exit with exit code 0 when no files are found instead of exit code 14.'
complete -c dprint -n "__fish_seen_subcommand_from fmt" -l skip-stable-format -d 'Whether to skip formatting a file multiple times until the output is stable'
complete -c dprint -n "__fish_seen_subcommand_from fmt" -l fail-on-change -d 'Exit with exit code 20 if files were formatted.'
complete -c dprint -n "__fish_seen_subcommand_from fmt" -l verbose -d 'Alias for --log-level=debug'
complete -c dprint -n "__fish_seen_subcommand_from fmt" -s h -l help -d 'Print help'
complete -c dprint -n "__fish_seen_subcommand_from check" -l includes-override -d 'List of file patterns in quotes to format. This overrides what is specified in the config file.' -r
complete -c dprint -n "__fish_seen_subcommand_from check" -l excludes -d 'List of file patterns or directories in quotes to exclude when formatting. This excludes in addition to what is found in the config file.' -r
complete -c dprint -n "__fish_seen_subcommand_from check" -l excludes-override -d 'List of file patterns or directories in quotes to exclude when formatting. This overrides what is specified in the config file.' -r
complete -c dprint -n "__fish_seen_subcommand_from check" -l incremental -d 'Only format files when they change. This may alternatively be specified in the configuration file.' -r -f -a "{true	'',false	''}"
complete -c dprint -n "__fish_seen_subcommand_from check" -l diff-format -d 'The format to output diffs in. Use `unified` to output a standard unified diff that can be piped to other tools or applied with `patch`. Defaults to `pretty`, or `unified` when outputting json.' -r -f -a "{pretty	'',unified	''}"
complete -c dprint -n "__fish_seen_subcommand_from check" -l fail-fast -d 'Stop checking files and exit on the first file that isn\'t formatted.' -r -f -a "{true	'',false	''}"
complete -c dprint -n "__fish_seen_subcommand_from check" -s c -l config -d 'Path or url to JSON configuration file. Defaults to dprint.json(c) or .dprint.json(c) in current or ancestor directory when not provided.' -r -F
complete -c dprint -n "__fish_seen_subcommand_from check" -l config-discovery -d 'Sets the config discovery mode. Set to `false` to completely disable, `ignore-descendants` to avoid finding config files in child directories, or `global` to only use the global config file.' -r
complete -c dprint -n "__fish_seen_subcommand_from check" -l plugins -d 'List of urls or file paths of plugins to use. This overrides what is specified in the config file.' -r -F
complete -c dprint -n "__fish_seen_subcommand_from check" -s L -l log-level -d 'Set log level' -r -f -a "{debug	'',info	'',warn	'',error	'',silent	''}"
complete -c dprint -n "__fish_seen_subcommand_from check" -l stdin-files -d 'Read a newline-separated list of file paths to format from stdin instead of from the command line arguments.'
complete -c dprint -n "__fish_seen_subcommand_from check" -l allow-node-modules -d 'Allows traversing node module directories. This is implicit when the current working directory is within one (unstable - This flag will be renamed to be non-node specific in the future).'
complete -c dprint -n "__fish_seen_subcommand_from check" -l no-gitignore -d 'Disables respecting .gitignore files.'
complete -c dprint -n "__fish_seen_subcommand_from check" -l allow-no-files -d 'Causes dprint to exit with exit code 0 when no files are found instead of exit code 14.'
complete -c dprint -n "__fish_seen_subcommand_from check" -l staged -d 'Format only the staged files.'
complete -c dprint -n "__fish_seen_subcommand_from check" -l dirty -d 'Format only the files with uncommitted changes in the git working directory (staged, unstaged, and untracked).'
complete -c dprint -n "__fish_seen_subcommand_from check" -l list-different -d 'Only outputs file paths that aren\'t formatted and doesn\'t output diffs.'
complete -c dprint -n "__fish_seen_subcommand_from check" -l json -d 'Outputs a JSON object per line for each file that isn\'t formatted.'
complete -c dprint -n "__fish_seen_subcommand_from check" -l verbose -d 'Alias for --log-level=debug'
complete -c dprint -n "__fish_seen_subcommand_from check" -s h -l help -d 'Print help'
complete -c dprint -n "__fish_seen_subcommand_from config; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from help" -s c -l config -d 'Path or url to JSON configuration file. Defaults to dprint.json(c) or .dprint.json(c) in current or ancestor directory when not provided.' -r -F
complete -c dprint -n "__fish_seen_subcommand_from config; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from help" -l config-discovery -d 'Sets the config discovery mode. Set to `false` to completely disable, `ignore-descendants` to avoid finding config files in child directories, or `global` to only use the global config file.' -r
complete -c dprint -n "__fish_seen_subcommand_from config; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from help" -l plugins -d 'List of urls or file paths of plugins to use. This overrides what is specified in the config file.' -r -F
complete -c dprint -n "__fish_seen_subcommand_from config; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from help" -s L -l log-level -d 'Set log level' -r -f -a "{debug	'',info	'',warn	'',error	'',silent	''}"
complete -c dprint -n "__fish_seen_subcommand_from config; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from help" -l verbose -d 'Alias for --log-level=debug'
complete -c dprint -n "__fish_seen_subcommand_from config; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from help" -s h -l help -d 'Print help'
complete -c dprint -n "__fish_seen_subcommand_from config; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from help" -f -a "init" -d 'Initializes a configuration file in the current directory.'
complete -c dprint -n "__fish_seen_subcommand_from config; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from help" -f -a "update" -d 'Updates the plugins in the configuration file.'
complete -c dprint -n "__fish_seen_subcommand_from config; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from help" -f -a "add" -d 'Adds a plugin to the configuration file.'
complete -c dprint -n "__fish_seen_subcommand_from config; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from help" -f -a "edit" -d 'Opens the configuration file in an editor.'
complete -c dprint -n "__fish_seen_subcommand_from config; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c dprint -n "__fish_seen_subcommand_from config; and __fish_seen_subcommand_from init" -l minimum-dependency-age -d 'Don\'t resolve npm plugin versions published more recently than this. Accepts an ISO-8601 duration (ex. \'P3D\', \'PT72H\'), a number of minutes (ex. \'1440\'), a date or RFC3339 timestamp (ex. \'2026-01-15\'), or \'0\' to disable. Defaults to min-release-age in .npmrc, otherwise no minimum.' -r
complete -c dprint -n "__fish_seen_subcommand_from config; and __fish_seen_subcommand_from init" -s c -l config -d 'Path or url to JSON configuration file. Defaults to dprint.json(c) or .dprint.json(c) in current or ancestor directory when not provided.' -r -F
complete -c dprint -n "__fish_seen_subcommand_from config; and __fish_seen_subcommand_from init" -l config-discovery -d 'Sets the config discovery mode. Set to `false` to completely disable, `ignore-descendants` to avoid finding config files in child directories, or `global` to only use the global config file.' -r
complete -c dprint -n "__fish_seen_subcommand_from config; and __fish_seen_subcommand_from init" -l plugins -d 'List of urls or file paths of plugins to use. This overrides what is specified in the config file.' -r -F
complete -c dprint -n "__fish_seen_subcommand_from config; and __fish_seen_subcommand_from init" -s L -l log-level -d 'Set log level' -r -f -a "{debug	'',info	'',warn	'',error	'',silent	''}"
complete -c dprint -n "__fish_seen_subcommand_from config; and __fish_seen_subcommand_from init" -s g -l global -d 'Initialize the global dprint configuration file.'
complete -c dprint -n "__fish_seen_subcommand_from config; and __fish_seen_subcommand_from init" -s y -l yes -d 'Skip the interactive plugin prompt and accept the plugins selected based on the files in the current directory.'
complete -c dprint -n "__fish_seen_subcommand_from config; and __fish_seen_subcommand_from init" -l verbose -d 'Alias for --log-level=debug'
complete -c dprint -n "__fish_seen_subcommand_from config; and __fish_seen_subcommand_from init" -s h -l help -d 'Print help'
complete -c dprint -n "__fish_seen_subcommand_from config; and __fish_seen_subcommand_from update" -l minimum-dependency-age -d 'Don\'t resolve npm plugin versions published more recently than this. Accepts an ISO-8601 duration (ex. \'P3D\', \'PT72H\'), a number of minutes (ex. \'1440\'), a date or RFC3339 timestamp (ex. \'2026-01-15\'), or \'0\' to disable. Defaults to min-release-age in .npmrc, otherwise no minimum.' -r
complete -c dprint -n "__fish_seen_subcommand_from config; and __fish_seen_subcommand_from update" -s c -l config -d 'Path or url to JSON configuration file. Defaults to dprint.json(c) or .dprint.json(c) in current or ancestor directory when not provided.' -r -F
complete -c dprint -n "__fish_seen_subcommand_from config; and __fish_seen_subcommand_from update" -l config-discovery -d 'Sets the config discovery mode. Set to `false` to completely disable, `ignore-descendants` to avoid finding config files in child directories, or `global` to only use the global config file.' -r
complete -c dprint -n "__fish_seen_subcommand_from config; and __fish_seen_subcommand_from update" -l plugins -d 'List of urls or file paths of plugins to use. This overrides what is specified in the config file.' -r -F
complete -c dprint -n "__fish_seen_subcommand_from config; and __fish_seen_subcommand_from update" -s L -l log-level -d 'Set log level' -r -f -a "{debug	'',info	'',warn	'',error	'',silent	''}"
complete -c dprint -n "__fish_seen_subcommand_from config; and __fish_seen_subcommand_from update" -s y -l yes -d 'Upgrade process plugins without prompting to confirm checksums.'
complete -c dprint -n "__fish_seen_subcommand_from config; and __fish_seen_subcommand_from update" -l dry-run -d 'Print the updates that would be made without modifying any files.'
complete -c dprint -n "__fish_seen_subcommand_from config; and __fish_seen_subcommand_from update" -s g -l global -d 'Update the global dprint configuration file.'
complete -c dprint -n "__fish_seen_subcommand_from config; and __fish_seen_subcommand_from update" -s r -l recursive -d 'Update configuration files in the current directory and all descendant directories.'
complete -c dprint -n "__fish_seen_subcommand_from config; and __fish_seen_subcommand_from update" -l verbose -d 'Alias for --log-level=debug'
complete -c dprint -n "__fish_seen_subcommand_from config; and __fish_seen_subcommand_from update" -s h -l help -d 'Print help'
complete -c dprint -n "__fish_seen_subcommand_from config; and __fish_seen_subcommand_from add" -l minimum-dependency-age -d 'Don\'t resolve npm plugin versions published more recently than this. Accepts an ISO-8601 duration (ex. \'P3D\', \'PT72H\'), a number of minutes (ex. \'1440\'), a date or RFC3339 timestamp (ex. \'2026-01-15\'), or \'0\' to disable. Defaults to min-release-age in .npmrc, otherwise no minimum.' -r
complete -c dprint -n "__fish_seen_subcommand_from config; and __fish_seen_subcommand_from add" -s c -l config -d 'Path or url to JSON configuration file. Defaults to dprint.json(c) or .dprint.json(c) in current or ancestor directory when not provided.' -r -F
complete -c dprint -n "__fish_seen_subcommand_from config; and __fish_seen_subcommand_from add" -l config-discovery -d 'Sets the config discovery mode. Set to `false` to completely disable, `ignore-descendants` to avoid finding config files in child directories, or `global` to only use the global config file.' -r
complete -c dprint -n "__fish_seen_subcommand_from config; and __fish_seen_subcommand_from add" -l plugins -d 'List of urls or file paths of plugins to use. This overrides what is specified in the config file.' -r -F
complete -c dprint -n "__fish_seen_subcommand_from config; and __fish_seen_subcommand_from add" -s L -l log-level -d 'Set log level' -r -f -a "{debug	'',info	'',warn	'',error	'',silent	''}"
complete -c dprint -n "__fish_seen_subcommand_from config; and __fish_seen_subcommand_from add" -s g -l global -d 'Add to the global dprint configuration file.'
complete -c dprint -n "__fish_seen_subcommand_from config; and __fish_seen_subcommand_from add" -l no-version -d 'For npm: specifiers, write the unversioned form instead of pinning dist-tags.latest. Defers version management to node_modules / package.json.'
complete -c dprint -n "__fish_seen_subcommand_from config; and __fish_seen_subcommand_from add" -l package-json -d 'Like --no-version, and also add the package to the nearest package.json\'s devDependencies as a caret range.'
complete -c dprint -n "__fish_seen_subcommand_from config; and __fish_seen_subcommand_from add" -l checksum -d 'Add a checksum to the plugin entry, even for Wasm plugins (which are otherwise added without one).'
complete -c dprint -n "__fish_seen_subcommand_from config; and __fish_seen_subcommand_from add" -l verbose -d 'Alias for --log-level=debug'
complete -c dprint -n "__fish_seen_subcommand_from config; and __fish_seen_subcommand_from add" -s h -l help -d 'Print help'
complete -c dprint -n "__fish_seen_subcommand_from config; and __fish_seen_subcommand_from edit" -s c -l config -d 'Path or url to JSON configuration file. Defaults to dprint.json(c) or .dprint.json(c) in current or ancestor directory when not provided.' -r -F
complete -c dprint -n "__fish_seen_subcommand_from config; and __fish_seen_subcommand_from edit" -l config-discovery -d 'Sets the config discovery mode. Set to `false` to completely disable, `ignore-descendants` to avoid finding config files in child directories, or `global` to only use the global config file.' -r
complete -c dprint -n "__fish_seen_subcommand_from config; and __fish_seen_subcommand_from edit" -l plugins -d 'List of urls or file paths of plugins to use. This overrides what is specified in the config file.' -r -F
complete -c dprint -n "__fish_seen_subcommand_from config; and __fish_seen_subcommand_from edit" -s L -l log-level -d 'Set log level' -r -f -a "{debug	'',info	'',warn	'',error	'',silent	''}"
complete -c dprint -n "__fish_seen_subcommand_from config; and __fish_seen_subcommand_from edit" -s g -l global -d 'Edit the global dprint configuration file.'
complete -c dprint -n "__fish_seen_subcommand_from config; and __fish_seen_subcommand_from edit" -l verbose -d 'Alias for --log-level=debug'
complete -c dprint -n "__fish_seen_subcommand_from config; and __fish_seen_subcommand_from edit" -s h -l help -d 'Print help'
complete -c dprint -n "__fish_seen_subcommand_from config; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from help" -f -a "init" -d 'Initializes a configuration file in the current directory.'
complete -c dprint -n "__fish_seen_subcommand_from config; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from help" -f -a "update" -d 'Updates the plugins in the configuration file.'
complete -c dprint -n "__fish_seen_subcommand_from config; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from help" -f -a "add" -d 'Adds a plugin to the configuration file.'
complete -c dprint -n "__fish_seen_subcommand_from config; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from help" -f -a "edit" -d 'Opens the configuration file in an editor.'
complete -c dprint -n "__fish_seen_subcommand_from config; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c dprint -n "__fish_seen_subcommand_from file-paths" -l includes-override -d 'List of file patterns in quotes to format. This overrides what is specified in the config file.' -r
complete -c dprint -n "__fish_seen_subcommand_from file-paths" -l excludes -d 'List of file patterns or directories in quotes to exclude when formatting. This excludes in addition to what is found in the config file.' -r
complete -c dprint -n "__fish_seen_subcommand_from file-paths" -l excludes-override -d 'List of file patterns or directories in quotes to exclude when formatting. This overrides what is specified in the config file.' -r
complete -c dprint -n "__fish_seen_subcommand_from file-paths" -s c -l config -d 'Path or url to JSON configuration file. Defaults to dprint.json(c) or .dprint.json(c) in current or ancestor directory when not provided.' -r -F
complete -c dprint -n "__fish_seen_subcommand_from file-paths" -l config-discovery -d 'Sets the config discovery mode. Set to `false` to completely disable, `ignore-descendants` to avoid finding config files in child directories, or `global` to only use the global config file.' -r
complete -c dprint -n "__fish_seen_subcommand_from file-paths" -l plugins -d 'List of urls or file paths of plugins to use. This overrides what is specified in the config file.' -r -F
complete -c dprint -n "__fish_seen_subcommand_from file-paths" -s L -l log-level -d 'Set log level' -r -f -a "{debug	'',info	'',warn	'',error	'',silent	''}"
complete -c dprint -n "__fish_seen_subcommand_from file-paths" -l stdin-files -d 'Read a newline-separated list of file paths to format from stdin instead of from the command line arguments.'
complete -c dprint -n "__fish_seen_subcommand_from file-paths" -l allow-node-modules -d 'Allows traversing node module directories. This is implicit when the current working directory is within one (unstable - This flag will be renamed to be non-node specific in the future).'
complete -c dprint -n "__fish_seen_subcommand_from file-paths" -l no-gitignore -d 'Disables respecting .gitignore files.'
complete -c dprint -n "__fish_seen_subcommand_from file-paths" -l staged -d 'Format only the staged files.'
complete -c dprint -n "__fish_seen_subcommand_from file-paths" -l dirty -d 'Format only the files with uncommitted changes in the git working directory (staged, unstaged, and untracked).'
complete -c dprint -n "__fish_seen_subcommand_from file-paths" -l verbose -d 'Alias for --log-level=debug'
complete -c dprint -n "__fish_seen_subcommand_from file-paths" -s h -l help -d 'Print help'
complete -c dprint -n "__fish_seen_subcommand_from resolved-config" -l file -d 'Limit the output to only the plugins that would format this file.' -r -F
complete -c dprint -n "__fish_seen_subcommand_from resolved-config" -s c -l config -d 'Path or url to JSON configuration file. Defaults to dprint.json(c) or .dprint.json(c) in current or ancestor directory when not provided.' -r -F
complete -c dprint -n "__fish_seen_subcommand_from resolved-config" -l config-discovery -d 'Sets the config discovery mode. Set to `false` to completely disable, `ignore-descendants` to avoid finding config files in child directories, or `global` to only use the global config file.' -r
complete -c dprint -n "__fish_seen_subcommand_from resolved-config" -l plugins -d 'List of urls or file paths of plugins to use. This overrides what is specified in the config file.' -r -F
complete -c dprint -n "__fish_seen_subcommand_from resolved-config" -s L -l log-level -d 'Set log level' -r -f -a "{debug	'',info	'',warn	'',error	'',silent	''}"
complete -c dprint -n "__fish_seen_subcommand_from resolved-config" -l verbose -d 'Alias for --log-level=debug'
complete -c dprint -n "__fish_seen_subcommand_from resolved-config" -s h -l help -d 'Print help'
complete -c dprint -n "__fish_seen_subcommand_from incremental-state" -s c -l config -d 'Path or url to JSON configuration file. Defaults to dprint.json(c) or .dprint.json(c) in current or ancestor directory when not provided.' -r -F
complete -c dprint -n "__fish_seen_subcommand_from incremental-state" -l config-discovery -d 'Sets the config discovery mode. Set to `false` to completely disable, `ignore-descendants` to avoid finding config files in child directories, or `global` to only use the global config file.' -r
complete -c dprint -n "__fish_seen_subcommand_from incremental-state" -l plugins -d 'List of urls or file paths of plugins to use. This overrides what is specified in the config file.' -r -F
complete -c dprint -n "__fish_seen_subcommand_from incremental-state" -s L -l log-level -d 'Set log level' -r -f -a "{debug	'',info	'',warn	'',error	'',silent	''}"
complete -c dprint -n "__fish_seen_subcommand_from incremental-state" -l verbose -d 'Alias for --log-level=debug'
complete -c dprint -n "__fish_seen_subcommand_from incremental-state" -s h -l help -d 'Print help'
complete -c dprint -n "__fish_seen_subcommand_from format-times" -l includes-override -d 'List of file patterns in quotes to format. This overrides what is specified in the config file.' -r
complete -c dprint -n "__fish_seen_subcommand_from format-times" -l excludes -d 'List of file patterns or directories in quotes to exclude when formatting. This excludes in addition to what is found in the config file.' -r
complete -c dprint -n "__fish_seen_subcommand_from format-times" -l excludes-override -d 'List of file patterns or directories in quotes to exclude when formatting. This overrides what is specified in the config file.' -r
complete -c dprint -n "__fish_seen_subcommand_from format-times" -s c -l config -d 'Path or url to JSON configuration file. Defaults to dprint.json(c) or .dprint.json(c) in current or ancestor directory when not provided.' -r -F
complete -c dprint -n "__fish_seen_subcommand_from format-times" -l config-discovery -d 'Sets the config discovery mode. Set to `false` to completely disable, `ignore-descendants` to avoid finding config files in child directories, or `global` to only use the global config file.' -r
complete -c dprint -n "__fish_seen_subcommand_from format-times" -l plugins -d 'List of urls or file paths of plugins to use. This overrides what is specified in the config file.' -r -F
complete -c dprint -n "__fish_seen_subcommand_from format-times" -s L -l log-level -d 'Set log level' -r -f -a "{debug	'',info	'',warn	'',error	'',silent	''}"
complete -c dprint -n "__fish_seen_subcommand_from format-times" -l stdin-files -d 'Read a newline-separated list of file paths to format from stdin instead of from the command line arguments.'
complete -c dprint -n "__fish_seen_subcommand_from format-times" -l allow-node-modules -d 'Allows traversing node module directories. This is implicit when the current working directory is within one (unstable - This flag will be renamed to be non-node specific in the future).'
complete -c dprint -n "__fish_seen_subcommand_from format-times" -l no-gitignore -d 'Disables respecting .gitignore files.'
complete -c dprint -n "__fish_seen_subcommand_from format-times" -l allow-no-files -d 'Causes dprint to exit with exit code 0 when no files are found instead of exit code 14.'
complete -c dprint -n "__fish_seen_subcommand_from format-times" -l staged -d 'Format only the staged files.'
complete -c dprint -n "__fish_seen_subcommand_from format-times" -l dirty -d 'Format only the files with uncommitted changes in the git working directory (staged, unstaged, and untracked).'
complete -c dprint -n "__fish_seen_subcommand_from format-times" -l verbose -d 'Alias for --log-level=debug'
complete -c dprint -n "__fish_seen_subcommand_from format-times" -s h -l help -d 'Print help'
complete -c dprint -n "__fish_seen_subcommand_from clear-cache" -s c -l config -d 'Path or url to JSON configuration file. Defaults to dprint.json(c) or .dprint.json(c) in current or ancestor directory when not provided.' -r -F
complete -c dprint -n "__fish_seen_subcommand_from clear-cache" -l config-discovery -d 'Sets the config discovery mode. Set to `false` to completely disable, `ignore-descendants` to avoid finding config files in child directories, or `global` to only use the global config file.' -r
complete -c dprint -n "__fish_seen_subcommand_from clear-cache" -l plugins -d 'List of urls or file paths of plugins to use. This overrides what is specified in the config file.' -r -F
complete -c dprint -n "__fish_seen_subcommand_from clear-cache" -s L -l log-level -d 'Set log level' -r -f -a "{debug	'',info	'',warn	'',error	'',silent	''}"
complete -c dprint -n "__fish_seen_subcommand_from clear-cache" -l verbose -d 'Alias for --log-level=debug'
complete -c dprint -n "__fish_seen_subcommand_from clear-cache" -s h -l help -d 'Print help'
complete -c dprint -n "__fish_seen_subcommand_from upgrade" -s c -l config -d 'Path or url to JSON configuration file. Defaults to dprint.json(c) or .dprint.json(c) in current or ancestor directory when not provided.' -r -F
complete -c dprint -n "__fish_seen_subcommand_from upgrade" -l config-discovery -d 'Sets the config discovery mode. Set to `false` to completely disable, `ignore-descendants` to avoid finding config files in child directories, or `global` to only use the global config file.' -r
complete -c dprint -n "__fish_seen_subcommand_from upgrade" -l plugins -d 'List of urls or file paths of plugins to use. This overrides what is specified in the config file.' -r -F
complete -c dprint -n "__fish_seen_subcommand_from upgrade" -s L -l log-level -d 'Set log level' -r -f -a "{debug	'',info	'',warn	'',error	'',silent	''}"
complete -c dprint -n "__fish_seen_subcommand_from upgrade" -l verbose -d 'Alias for --log-level=debug'
complete -c dprint -n "__fish_seen_subcommand_from upgrade" -s h -l help -d 'Print help'
complete -c dprint -n "__fish_seen_subcommand_from completions" -s c -l config -d 'Path or url to JSON configuration file. Defaults to dprint.json(c) or .dprint.json(c) in current or ancestor directory when not provided.' -r -F
complete -c dprint -n "__fish_seen_subcommand_from completions" -l config-discovery -d 'Sets the config discovery mode. Set to `false` to completely disable, `ignore-descendants` to avoid finding config files in child directories, or `global` to only use the global config file.' -r
complete -c dprint -n "__fish_seen_subcommand_from completions" -l plugins -d 'List of urls or file paths of plugins to use. This overrides what is specified in the config file.' -r -F
complete -c dprint -n "__fish_seen_subcommand_from completions" -s L -l log-level -d 'Set log level' -r -f -a "{debug	'',info	'',warn	'',error	'',silent	''}"
complete -c dprint -n "__fish_seen_subcommand_from completions" -l verbose -d 'Alias for --log-level=debug'
complete -c dprint -n "__fish_seen_subcommand_from completions" -s h -l help -d 'Print help'
complete -c dprint -n "__fish_seen_subcommand_from license" -s c -l config -d 'Path or url to JSON configuration file. Defaults to dprint.json(c) or .dprint.json(c) in current or ancestor directory when not provided.' -r -F
complete -c dprint -n "__fish_seen_subcommand_from license" -l config-discovery -d 'Sets the config discovery mode. Set to `false` to completely disable, `ignore-descendants` to avoid finding config files in child directories, or `global` to only use the global config file.' -r
complete -c dprint -n "__fish_seen_subcommand_from license" -l plugins -d 'List of urls or file paths of plugins to use. This overrides what is specified in the config file.' -r -F
complete -c dprint -n "__fish_seen_subcommand_from license" -s L -l log-level -d 'Set log level' -r -f -a "{debug	'',info	'',warn	'',error	'',silent	''}"
complete -c dprint -n "__fish_seen_subcommand_from license" -l verbose -d 'Alias for --log-level=debug'
complete -c dprint -n "__fish_seen_subcommand_from license" -s h -l help -d 'Print help'
complete -c dprint -n "__fish_seen_subcommand_from editor-info" -s c -l config -d 'Path or url to JSON configuration file. Defaults to dprint.json(c) or .dprint.json(c) in current or ancestor directory when not provided.' -r -F
complete -c dprint -n "__fish_seen_subcommand_from editor-info" -l config-discovery -d 'Sets the config discovery mode. Set to `false` to completely disable, `ignore-descendants` to avoid finding config files in child directories, or `global` to only use the global config file.' -r
complete -c dprint -n "__fish_seen_subcommand_from editor-info" -l plugins -d 'List of urls or file paths of plugins to use. This overrides what is specified in the config file.' -r -F
complete -c dprint -n "__fish_seen_subcommand_from editor-info" -s L -l log-level -d 'Set log level' -r -f -a "{debug	'',info	'',warn	'',error	'',silent	''}"
complete -c dprint -n "__fish_seen_subcommand_from editor-info" -l verbose -d 'Alias for --log-level=debug'
complete -c dprint -n "__fish_seen_subcommand_from editor-info" -s h -l help -d 'Print help'
complete -c dprint -n "__fish_seen_subcommand_from editor-service" -l parent-pid -r
complete -c dprint -n "__fish_seen_subcommand_from editor-service" -s c -l config -d 'Path or url to JSON configuration file. Defaults to dprint.json(c) or .dprint.json(c) in current or ancestor directory when not provided.' -r -F
complete -c dprint -n "__fish_seen_subcommand_from editor-service" -l config-discovery -d 'Sets the config discovery mode. Set to `false` to completely disable, `ignore-descendants` to avoid finding config files in child directories, or `global` to only use the global config file.' -r
complete -c dprint -n "__fish_seen_subcommand_from editor-service" -l plugins -d 'List of urls or file paths of plugins to use. This overrides what is specified in the config file.' -r -F
complete -c dprint -n "__fish_seen_subcommand_from editor-service" -s L -l log-level -d 'Set log level' -r -f -a "{debug	'',info	'',warn	'',error	'',silent	''}"
complete -c dprint -n "__fish_seen_subcommand_from editor-service" -l verbose -d 'Alias for --log-level=debug'
complete -c dprint -n "__fish_seen_subcommand_from editor-service" -s h -l help -d 'Print help'
complete -c dprint -n "__fish_seen_subcommand_from lsp" -s c -l config -d 'Path or url to JSON configuration file. Defaults to dprint.json(c) or .dprint.json(c) in current or ancestor directory when not provided.' -r -F
complete -c dprint -n "__fish_seen_subcommand_from lsp" -l config-discovery -d 'Sets the config discovery mode. Set to `false` to completely disable, `ignore-descendants` to avoid finding config files in child directories, or `global` to only use the global config file.' -r
complete -c dprint -n "__fish_seen_subcommand_from lsp" -l plugins -d 'List of urls or file paths of plugins to use. This overrides what is specified in the config file.' -r -F
complete -c dprint -n "__fish_seen_subcommand_from lsp" -s L -l log-level -d 'Set log level' -r -f -a "{debug	'',info	'',warn	'',error	'',silent	''}"
complete -c dprint -n "__fish_seen_subcommand_from lsp" -l verbose -d 'Alias for --log-level=debug'
complete -c dprint -n "__fish_seen_subcommand_from lsp" -s h -l help -d 'Print help'
complete -c dprint -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from check; and not __fish_seen_subcommand_from config; and not __fish_seen_subcommand_from file-paths; and not __fish_seen_subcommand_from resolved-config; and not __fish_seen_subcommand_from incremental-state; and not __fish_seen_subcommand_from format-times; and not __fish_seen_subcommand_from clear-cache; and not __fish_seen_subcommand_from upgrade; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from license; and not __fish_seen_subcommand_from editor-info; and not __fish_seen_subcommand_from editor-service; and not __fish_seen_subcommand_from lsp; and not __fish_seen_subcommand_from help" -f -a "init" -d 'Initializes a configuration file in the current directory.'
complete -c dprint -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from check; and not __fish_seen_subcommand_from config; and not __fish_seen_subcommand_from file-paths; and not __fish_seen_subcommand_from resolved-config; and not __fish_seen_subcommand_from incremental-state; and not __fish_seen_subcommand_from format-times; and not __fish_seen_subcommand_from clear-cache; and not __fish_seen_subcommand_from upgrade; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from license; and not __fish_seen_subcommand_from editor-info; and not __fish_seen_subcommand_from editor-service; and not __fish_seen_subcommand_from lsp; and not __fish_seen_subcommand_from help" -f -a "add" -d 'Adds a plugin to the configuration file.'
complete -c dprint -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from check; and not __fish_seen_subcommand_from config; and not __fish_seen_subcommand_from file-paths; and not __fish_seen_subcommand_from resolved-config; and not __fish_seen_subcommand_from incremental-state; and not __fish_seen_subcommand_from format-times; and not __fish_seen_subcommand_from clear-cache; and not __fish_seen_subcommand_from upgrade; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from license; and not __fish_seen_subcommand_from editor-info; and not __fish_seen_subcommand_from editor-service; and not __fish_seen_subcommand_from lsp; and not __fish_seen_subcommand_from help" -f -a "fmt" -d 'Formats the source files and writes the result to the file system.'
complete -c dprint -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from check; and not __fish_seen_subcommand_from config; and not __fish_seen_subcommand_from file-paths; and not __fish_seen_subcommand_from resolved-config; and not __fish_seen_subcommand_from incremental-state; and not __fish_seen_subcommand_from format-times; and not __fish_seen_subcommand_from clear-cache; and not __fish_seen_subcommand_from upgrade; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from license; and not __fish_seen_subcommand_from editor-info; and not __fish_seen_subcommand_from editor-service; and not __fish_seen_subcommand_from lsp; and not __fish_seen_subcommand_from help" -f -a "check" -d 'Checks for any files that haven\'t been formatted.'
complete -c dprint -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from check; and not __fish_seen_subcommand_from config; and not __fish_seen_subcommand_from file-paths; and not __fish_seen_subcommand_from resolved-config; and not __fish_seen_subcommand_from incremental-state; and not __fish_seen_subcommand_from format-times; and not __fish_seen_subcommand_from clear-cache; and not __fish_seen_subcommand_from upgrade; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from license; and not __fish_seen_subcommand_from editor-info; and not __fish_seen_subcommand_from editor-service; and not __fish_seen_subcommand_from lsp; and not __fish_seen_subcommand_from help" -f -a "config" -d 'Functionality related to the configuration file.'
complete -c dprint -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from check; and not __fish_seen_subcommand_from config; and not __fish_seen_subcommand_from file-paths; and not __fish_seen_subcommand_from resolved-config; and not __fish_seen_subcommand_from incremental-state; and not __fish_seen_subcommand_from format-times; and not __fish_seen_subcommand_from clear-cache; and not __fish_seen_subcommand_from upgrade; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from license; and not __fish_seen_subcommand_from editor-info; and not __fish_seen_subcommand_from editor-service; and not __fish_seen_subcommand_from lsp; and not __fish_seen_subcommand_from help" -f -a "file-paths" -d 'Prints the resolved file paths for the plugins based on the args and configuration.'
complete -c dprint -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from check; and not __fish_seen_subcommand_from config; and not __fish_seen_subcommand_from file-paths; and not __fish_seen_subcommand_from resolved-config; and not __fish_seen_subcommand_from incremental-state; and not __fish_seen_subcommand_from format-times; and not __fish_seen_subcommand_from clear-cache; and not __fish_seen_subcommand_from upgrade; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from license; and not __fish_seen_subcommand_from editor-info; and not __fish_seen_subcommand_from editor-service; and not __fish_seen_subcommand_from lsp; and not __fish_seen_subcommand_from help" -f -a "resolved-config" -d 'Prints the resolved configuration for the plugins based on the args and configuration.'
complete -c dprint -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from check; and not __fish_seen_subcommand_from config; and not __fish_seen_subcommand_from file-paths; and not __fish_seen_subcommand_from resolved-config; and not __fish_seen_subcommand_from incremental-state; and not __fish_seen_subcommand_from format-times; and not __fish_seen_subcommand_from clear-cache; and not __fish_seen_subcommand_from upgrade; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from license; and not __fish_seen_subcommand_from editor-info; and not __fish_seen_subcommand_from editor-service; and not __fish_seen_subcommand_from lsp; and not __fish_seen_subcommand_from help" -f -a "incremental-state" -d 'Prints the state used to determine whether the incremental cache would be invalidated.'
complete -c dprint -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from check; and not __fish_seen_subcommand_from config; and not __fish_seen_subcommand_from file-paths; and not __fish_seen_subcommand_from resolved-config; and not __fish_seen_subcommand_from incremental-state; and not __fish_seen_subcommand_from format-times; and not __fish_seen_subcommand_from clear-cache; and not __fish_seen_subcommand_from upgrade; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from license; and not __fish_seen_subcommand_from editor-info; and not __fish_seen_subcommand_from editor-service; and not __fish_seen_subcommand_from lsp; and not __fish_seen_subcommand_from help" -f -a "format-times" -d 'Prints the amount of time it takes to format each file. Use this for debugging.'
complete -c dprint -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from check; and not __fish_seen_subcommand_from config; and not __fish_seen_subcommand_from file-paths; and not __fish_seen_subcommand_from resolved-config; and not __fish_seen_subcommand_from incremental-state; and not __fish_seen_subcommand_from format-times; and not __fish_seen_subcommand_from clear-cache; and not __fish_seen_subcommand_from upgrade; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from license; and not __fish_seen_subcommand_from editor-info; and not __fish_seen_subcommand_from editor-service; and not __fish_seen_subcommand_from lsp; and not __fish_seen_subcommand_from help" -f -a "clear-cache" -d 'Deletes the plugin cache directory.'
complete -c dprint -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from check; and not __fish_seen_subcommand_from config; and not __fish_seen_subcommand_from file-paths; and not __fish_seen_subcommand_from resolved-config; and not __fish_seen_subcommand_from incremental-state; and not __fish_seen_subcommand_from format-times; and not __fish_seen_subcommand_from clear-cache; and not __fish_seen_subcommand_from upgrade; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from license; and not __fish_seen_subcommand_from editor-info; and not __fish_seen_subcommand_from editor-service; and not __fish_seen_subcommand_from lsp; and not __fish_seen_subcommand_from help" -f -a "upgrade" -d 'Upgrades the dprint executable.'
complete -c dprint -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from check; and not __fish_seen_subcommand_from config; and not __fish_seen_subcommand_from file-paths; and not __fish_seen_subcommand_from resolved-config; and not __fish_seen_subcommand_from incremental-state; and not __fish_seen_subcommand_from format-times; and not __fish_seen_subcommand_from clear-cache; and not __fish_seen_subcommand_from upgrade; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from license; and not __fish_seen_subcommand_from editor-info; and not __fish_seen_subcommand_from editor-service; and not __fish_seen_subcommand_from lsp; and not __fish_seen_subcommand_from help" -f -a "completions" -d 'Generate shell completions script for dprint'
complete -c dprint -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from check; and not __fish_seen_subcommand_from config; and not __fish_seen_subcommand_from file-paths; and not __fish_seen_subcommand_from resolved-config; and not __fish_seen_subcommand_from incremental-state; and not __fish_seen_subcommand_from format-times; and not __fish_seen_subcommand_from clear-cache; and not __fish_seen_subcommand_from upgrade; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from license; and not __fish_seen_subcommand_from editor-info; and not __fish_seen_subcommand_from editor-service; and not __fish_seen_subcommand_from lsp; and not __fish_seen_subcommand_from help" -f -a "license" -d 'Outputs the software license.'
complete -c dprint -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from check; and not __fish_seen_subcommand_from config; and not __fish_seen_subcommand_from file-paths; and not __fish_seen_subcommand_from resolved-config; and not __fish_seen_subcommand_from incremental-state; and not __fish_seen_subcommand_from format-times; and not __fish_seen_subcommand_from clear-cache; and not __fish_seen_subcommand_from upgrade; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from license; and not __fish_seen_subcommand_from editor-info; and not __fish_seen_subcommand_from editor-service; and not __fish_seen_subcommand_from lsp; and not __fish_seen_subcommand_from help" -f -a "editor-info"
complete -c dprint -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from check; and not __fish_seen_subcommand_from config; and not __fish_seen_subcommand_from file-paths; and not __fish_seen_subcommand_from resolved-config; and not __fish_seen_subcommand_from incremental-state; and not __fish_seen_subcommand_from format-times; and not __fish_seen_subcommand_from clear-cache; and not __fish_seen_subcommand_from upgrade; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from license; and not __fish_seen_subcommand_from editor-info; and not __fish_seen_subcommand_from editor-service; and not __fish_seen_subcommand_from lsp; and not __fish_seen_subcommand_from help" -f -a "editor-service"
complete -c dprint -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from check; and not __fish_seen_subcommand_from config; and not __fish_seen_subcommand_from file-paths; and not __fish_seen_subcommand_from resolved-config; and not __fish_seen_subcommand_from incremental-state; and not __fish_seen_subcommand_from format-times; and not __fish_seen_subcommand_from clear-cache; and not __fish_seen_subcommand_from upgrade; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from license; and not __fish_seen_subcommand_from editor-info; and not __fish_seen_subcommand_from editor-service; and not __fish_seen_subcommand_from lsp; and not __fish_seen_subcommand_from help" -f -a "lsp" -d 'Starts up a language server for formatting files.'
complete -c dprint -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from check; and not __fish_seen_subcommand_from config; and not __fish_seen_subcommand_from file-paths; and not __fish_seen_subcommand_from resolved-config; and not __fish_seen_subcommand_from incremental-state; and not __fish_seen_subcommand_from format-times; and not __fish_seen_subcommand_from clear-cache; and not __fish_seen_subcommand_from upgrade; and not __fish_seen_subcommand_from completions; and not __fish_seen_subcommand_from license; and not __fish_seen_subcommand_from editor-info; and not __fish_seen_subcommand_from editor-service; and not __fish_seen_subcommand_from lsp; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c dprint -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from config; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from edit" -f -a "init" -d 'Initializes a configuration file in the current directory.'
complete -c dprint -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from config; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from edit" -f -a "update" -d 'Updates the plugins in the configuration file.'
complete -c dprint -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from config; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from edit" -f -a "add" -d 'Adds a plugin to the configuration file.'
complete -c dprint -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from config; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from update; and not __fish_seen_subcommand_from add; and not __fish_seen_subcommand_from edit" -f -a "edit" -d 'Opens the configuration file in an editor.'
